/**
   @file      all.h
   @author    Mitch Richling <richmit@member.ams.org>
   @Copyright Copyright 1997 by Mitch Richling.  All rights reserved.
   @brief     This is the include file that creates the file finder.@EOL
   @Keywords  none
   @Std       C89
*/

/* *************************************************************************** */
/* Functionality options */

/* Call a function one each file */
#define FILEACTION 1
#define INITACTION 0
#define EXITACTION 0

/* Exit on not fatal, bad arguments. */
#define BADARGEXIT 0

/* Trivial Errors cause an exit. */
#define TRIVERREXIT 0

/* Print the list as we process it */
#define PRINTLIST 0

/* Collect stastics */
#define DOSTATS 1

/* The delimiter to use after files.  Normally '\n', but '\0' is useful as well. */
#ifndef DELIM
#define DELIM '\n'
#endif

/* *************************************************************************** */
/* Tuning options */

/* Use memcpy instead of string functions. */
#define USEMEMCPY 0

/* Maximum number-1 of threads to run at one time. */
#define NUMTHREADS 55

/* Number of directories to read before updating global linked list. */
#define UPLOADTRIG 10

/* *************************************************************************** */
/* This is used for error messages. */
#define PROGNAME "all"

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int fileAction(struct stat s, char *name)
{
  pthread_mutex_lock(&console_mutex);
  if(S_ISDIR(s.st_mode)) {      /* Process directories. */
    printf("%s/%c", name, DELIM);
  } else {
    printf("%s%c", name, DELIM);
  }
  pthread_mutex_unlock(&console_mutex);
  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int initAction(int argc, char *argv[], int *idxFirstArg)
{
  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int exitAction(void)
{
  return 0;
}
