/**
   @file      du.h.c
   @author    Mitch Richling <richmit@member.ams.org>
   @Copyright Copyright 1997 by Mitch Richling.  All rights reserved.
   @brief     This is the include file that creates the owner finder.@EOL
   @Keywords  none
   @Std       C89
*/

/* *************************************************************************** */
/* Functionality options */

/* Call a function one each file */
#define FILEACTION 0
#define INITACTION 0
#define EXITACTION 1

/* Exit on not fatal, bad arguments. */
#define BADARGEXIT 0

/* Trivial Errors cause an exit. */
#define TRIVERREXIT 0

/* Print the list as we process it */
#define PRINTLIST 0

/* Collect stastics */
#define DOSTATS 1

/* *************************************************************************** */
/* Tuning options */

/* Use memcpy instead of string functions. */
#define USEMEMCPY 0

/* Maximum number-1 of threads to run at one time. */
#define NUMTHREADS 55

/* Number of directories to read before updating global linked list. */
#define UPLOADTRIG 10

/* *************************************************************************** */
/* This is used for error messages. */
#ifdef dirgo_du
#define PROGNAME "du"
#else
#define PROGNAME "dux"
#endif

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int fileAction(struct stat s, char *name)
{
  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int initAction(int argc, char *argv[], int *idxFirstArg)
{
  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int exitAction(void)
{
#ifdef dirgo_du
  printf("%ld\n", gblTotalBlks);
#else
  printf("Number of regular files...... %ld\n", gblNumFiles);
  printf("Number of links.............. %ld\n", gblNumLinks);
  printf("Number of directories........ %ld\n", gblNumDirs);
  printf("Number of special files...... %ld\n", gblNumSpecial);
  printf("Block Count.................. %ld\n", gblTotalBlks);
  printf("Total size................... %ld\n", gblTotalSize);
  printf("Total size (regular files)... %ld\n", gblTotalRegFileSize);
  printf("Block count (regular files).. %ld\n", gblTotalRegFileBlks);
  printf("Run Time (seconds)........... %ld\n", (long)(gblEndTime-gblStartTime));
#endif


  return 0;
}
