/**
   @file      own.h
   @author    Mitch Richling <richmit@member.ams.org>
   @Copyright Copyright 1997 by Mitch Richling.  All rights reserved.
   @brief     This is the include file that creates the owner finder@EOL
   @Keywords  none
   @Std       C89
*/

#include <ctype.h>

/* *************************************************************************** */
/* Functionality options */

/* Call a function one each file */
#define FILEACTION 1
#define INITACTION 1
#define EXITACTION 0

/* Exit on not fatal, bad arguments. */
#define BADARGEXIT 0

/* Trivial Errors cause an exit. */
#define TRIVERREXIT 0

/* Print the list as we process it */
#define PRINTLIST 0

/* Collect stastics */
#define DOSTATS 1

/* *************************************************************************** */
/* Tuning options */

/* Use memcpy instead of string functions. */
#define USEMEMCPY 0

/* Maximum number-1 of threads to run at one time. */
#define NUMTHREADS 55

/* Number of directories to read before updating global linked list. */
#define UPLOADTRIG 10

/* *************************************************************************** */
/* This is used for error messages. */
#ifdef dirgo_noown
#define PROGNAME "notown"
#else
#define PROGNAME "own"
#endif

/* *************************************************************************** */
/* Global vars for the program.  These are global for main.c */
#define MAX_UID 0xfffff
long int uidar[MAX_UID + 16];

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int fileAction(struct stat s, char *name)
{
#ifdef dirgo_noown
  if(!(uidar[s.st_uid])) {
#else
  if(uidar[s.st_uid]) {
#endif
    printf("%10ld  %s\n", (long int)s.st_uid, name);
  }
  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int initAction(int argc, char *argv[], int *idxFirstArg)
{
  long uid, i, line;
  char readBuff[1024], *p;
  FILE *FD;

  if(argc < 3) {
    if ((argc>1) && (argv[1][0] == '-') && (argv[1][1] == 'h'))
      printf("INFO(0): %s: USE: %s UID_FILE DIR [DIR...]\n", PROGNAME, PROGNAME);
    else
      printf("ERROR(12): %s: Not enough arguments (use -h for help)!\n", PROGNAME);
    exit(1);
  }

  *idxFirstArg = 2;

  /* Initialize the array holding the uids to look for(or not look for). */
  for(i = 0; i < MAX_UID; i++)
    uidar[i] = 0;
  /* Load the uid numbers from disk. */
  if((FD = fopen(argv[1], "r")) == NULL) {
    printf("ERROR(11): %s: open UID_FILE : %s\n", PROGNAME, argv[1]);
    exit(1);
  }
  line = 0;
  while(NULL != fgets(readBuff, 1000, FD)) {

    line++;
    for(p=readBuff; *p!='\0'; p++)
      if( !(isspace(*p) || isdigit(*p))) {
        printf("ERROR(15): %s: UID_FILE (%s:%ld) contains non-numeric data (%d)!\n", PROGNAME, argv[1], line, (int)(*p));
        exit(16);
      }
    uid = atol(readBuff);
    if (uidar[uid] >= MAX_UID) {
      printf("ERROR(11): %s: UID_FILE (%s:%ld) contains large UID: %ld!\n", PROGNAME, argv[1], line, uid);
      exit(15);
    }
    uidar[uid]++;
    if (uidar[uid] > 1) {
      printf("ERROR(11): %s: UID_FILE (%s:%ld) contains duplicate UID: %ld!\n", PROGNAME, argv[1], line, uid);
      exit(14);
    }
#if(DEBUG > 4)
    printf("UID Load: %10ld\n", atol(readBuff));
#endif
  }
  fclose(FD);

  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int exitAction(void)
{
  return (0);
}
