/**
   @file      age.h
   @author    Mitch Richling <richmit@member.ams.org>
   @Copyright Copyright 1998 by Mitch Richling.  All rights reserved.
   @brief     Include file for age report program.@EOL
   @Keywords  file age report multi-threaded
   @Std       C89

              This is the include file that creates the file age
              report program.  All the locking for the ageGbl*
              variables causes a serious bottleneck in this code;
              however, it is still relatively fast..
*/

/* *************************************************************************** */
/* Functionality options */

/* Call a function one each file */
#define FILEACTION 1
#define INITACTION 1
#define EXITACTION 1

/* Exit on not fatal, bad arguments. */
#define BADARGEXIT 0

/* Trivial Errors cause an exit. */
#define TRIVERREXIT 0

/* Print the list as we process it */
#define PRINTLIST 0

/* Collect statics */
#define DOSTATS 1

/* *************************************************************************** */
/* Tuning options */

/* Use memcpy instead of string functions. */
#define USEMEMCPY 0

/* Maximum number-1 of threads to run at one time. */
#define NUMTHREADS 55

/* Number of directories to read before updating global linked list. */
#define UPLOADTRIG 10

/* *************************************************************************** */
/* This is used for error messages. */
#define PROGNAME "age"

/* *************************************************************************** */
/* Global variables defined by this module. These are global to the main.c as well. */
#define NUMTBUCK 3
long int ageGblNumDirs[NUMTBUCK+2],   ageGblNumFiles[NUMTBUCK+2],  ageGblNumLinks[NUMTBUCK+2],         ageGblNumSpecial[NUMTBUCK+2];
long int ageGblTotalSize[NUMTBUCK+2], ageGblTotalBlks[NUMTBUCK+2], ageGblTotalRegFileSize[NUMTBUCK+2], ageGblTotalRegFileBlks[NUMTBUCK+2];
long int timeBuckets[NUMTBUCK] = {2592000, 5184000, 7776000};

#define MIN_UID 0x00000
#define MIN_GID 0x00000
#define MAX_UID 0xfffff
#define MAX_GID 0xfffff
long int uidNumFiles[MAX_UID+1];
long int gidNumFiles[MAX_GID+1];

/* Controls all the stats variables used by this code. */
pthread_mutex_t actionStats_mutex = PTHREAD_MUTEX_INITIALIZER;

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int fileAction(struct stat s, char *name) {

  pthread_mutex_lock(&actionStats_mutex);

  if( (s.st_gid >= MIN_GID) && (s.st_gid <= MAX_GID) )
    gidNumFiles[s.st_gid]++;

  if( (s.st_uid >= MIN_UID) && (s.st_uid <= MAX_UID) )
    uidNumFiles[s.st_uid]++;
    
  pthread_mutex_unlock(&actionStats_mutex);

  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int initAction(int argc, char *argv[], int *idxFirstArg) {
  int i;
  for(i = MIN_UID; i <= MAX_UID; i++)
    uidNumFiles[i] = 0;
  for(i = MIN_GID; i <= MAX_GID; i++)
    gidNumFiles[i] = 0;
  return (0);
}

/* *************************************************************************** */
/* This is meant to be overridden with useful stuff. */
int exitAction(void) {
  int i;

  for(i = MIN_UID; i <= MAX_UID; i++)
    if(uidNumFiles[i] > 0)
      printf("UID: %15d NUM_FIL: %15ld\n", i, uidNumFiles[i]);

  for(i = MIN_GID; i <= MAX_GID; i++)
    if(gidNumFiles[i] > 0)
      printf("GID: %15d NUM_FIL: %15ld\n", i, gidNumFiles[i]);

  return 0;
}
